==> pmml-model-gwt-1.4.8-sources.jar: org/dmg/pmml/neural_network/NeuralOutputs.java <==

package org.dmg.pmml.neural_network;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "neuralOutputs"
})
@XmlRootElement(name = "NeuralOutputs", namespace = "http://www.dmg.org/PMML-4_3")
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "numberOfOutputs",
    "extensions",
    "neuralOutputs"
})
public class NeuralOutputs
    extends org.dmg.pmml.PMMLObject
    implements Iterable<NeuralOutput> , HasExtensions<NeuralOutputs>
{

    @XmlAttribute(name = "numberOfOutputs")
    @JsonProperty("numberOfOutputs")
    private Integer numberOfOutputs;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "NeuralOutput", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    @JsonProperty("NeuralOutput")
    private List<NeuralOutput> neuralOutputs;
    private final static long serialVersionUID = 67305485L;

    public NeuralOutputs() {
    }

    public NeuralOutputs(
        @org.jpmml.model.annotations.Property("neuralOutputs")
        List<NeuralOutput> neuralOutputs) {
        this.neuralOutputs = neuralOutputs;
    }

    public Integer getNumberOfOutputs() {
        return numberOfOutputs;
    }

    public NeuralOutputs setNumberOfOutputs(
        @org.jpmml.model.annotations.Property("numberOfOutputs")
        Integer numberOfOutputs) {
        this.numberOfOutputs = numberOfOutputs;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public NeuralOutputs addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public Iterator<NeuralOutput> iterator() {
        return getNeuralOutputs().iterator();
    }

    public boolean hasNeuralOutputs() {
        return ((this.neuralOutputs!= null)&&(this.neuralOutputs.size()> 0));
    }

    public List<NeuralOutput> getNeuralOutputs() {
        if (neuralOutputs == null) {
            neuralOutputs = new ArrayList<NeuralOutput>();
        }
        return this.neuralOutputs;
    }

    public NeuralOutputs addNeuralOutputs(NeuralOutput... neuralOutputs) {
        getNeuralOutputs().addAll(Arrays.asList(neuralOutputs));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasNeuralOutputs()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getNeuralOutputs());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.4.13-sources.jar: org/dmg/pmml/neural_network/NeuralOutputs.java <==

package org.dmg.pmml.neural_network;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.NonNegativeIntegerAdapter;
import org.jpmml.model.annotations.ValueConstructor;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "neuralOutputs"
})
@XmlRootElement(name = "NeuralOutputs", namespace = "http://www.dmg.org/PMML-4_3")
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "numberOfOutputs",
    "extensions",
    "neuralOutputs"
})
public class NeuralOutputs
    extends org.dmg.pmml.PMMLObject
    implements Iterable<NeuralOutput> , HasExtensions<NeuralOutputs>
{

    @XmlAttribute(name = "numberOfOutputs")
    @XmlJavaTypeAdapter(NonNegativeIntegerAdapter.class)
    @XmlSchemaType(name = "nonNegativeInteger")
    @JsonProperty("numberOfOutputs")
    private Integer numberOfOutputs;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "NeuralOutput", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    @JsonProperty("NeuralOutput")
    private List<NeuralOutput> neuralOutputs;
    private final static long serialVersionUID = 67305489L;

    public NeuralOutputs() {
    }

    @ValueConstructor
    public NeuralOutputs(
        @org.jpmml.model.annotations.Property("neuralOutputs")
        List<NeuralOutput> neuralOutputs) {
        this.neuralOutputs = neuralOutputs;
    }

    public Integer getNumberOfOutputs() {
        return numberOfOutputs;
    }

    public NeuralOutputs setNumberOfOutputs(
        @org.jpmml.model.annotations.Property("numberOfOutputs")
        Integer numberOfOutputs) {
        this.numberOfOutputs = numberOfOutputs;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public NeuralOutputs addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public Iterator<NeuralOutput> iterator() {
        return getNeuralOutputs().iterator();
    }

    public boolean hasNeuralOutputs() {
        return ((this.neuralOutputs!= null)&&(this.neuralOutputs.size()> 0));
    }

    public List<NeuralOutput> getNeuralOutputs() {
        if (neuralOutputs == null) {
            neuralOutputs = new ArrayList<NeuralOutput>();
        }
        return this.neuralOutputs;
    }

    public NeuralOutputs addNeuralOutputs(NeuralOutput... neuralOutputs) {
        getNeuralOutputs().addAll(Arrays.asList(neuralOutputs));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasNeuralOutputs()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getNeuralOutputs());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
